<?php

namespace Drupal\messagebird\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Locale\CountryManager;

/**
 * Class MessagebirdTestForm.
 *
 * @package Drupal\messagebird
 */
class LookupTestForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'messagebird_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['number'] = array(
      '#type' => 'tel',
      '#title' => t('Number'),
      '#required' => TRUE,
      '#description' => t('Multiple formats are supported based on the optional country code.'),
    );

    $form['country'] = array(
      '#type' => 'select',
      '#title' => $this->t('Country'),
      '#description' => $this->t('Choose the country of the %title origin.', array('%title' => $form['number']['#title'])),
      '#title_display' => 'before',
      '#empty_option' => $this->t('- Choose  -'),
      '#options' => CountryManager::getStandardList(),
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Lookup number'),
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    /** @var \Drupal\messagebird\MessageBirdLookupInterface $messagebird */
    $messagebird = \Drupal::service('messagebird.lookup');

    $country = $form_state->isValueEmpty('country') ? NULL : $form_state->getValue('country');
    $lookup = $messagebird->lookupNumber($form_state->getValue('number'), $country);

    if (is_null($lookup)) {
      $form_state->setError($form['number'], t('Invalid phone number.'));
    }
    else {
      $form_state->set('lookup', $lookup);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\messagebird\MessageBirdLookupInterface $messagebird */
    $messagebird = \Drupal::service('messagebird.lookup');

    $lookup = $form_state->get('lookup');
    if ($lookup) {
      $number = $messagebird->getPhoneNumber($lookup);
      drupal_set_message(t('Valid phone number: %number', array('%number' => $number)));
    }
  }

}
