<?php

namespace Drupal\messagebird\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use MessageBird\Objects\Recipient;

/**
 * Class MessagebirdTestForm.
 *
 * @package Drupal\messagebird
 */
class MessageTestForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'messagebird_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['originator'] = array(
      '#type' => 'textfield',
      '#title' => t('Originator'),
    );

    $form['recipients'] = array(
      '#type' => 'textfield',
      '#title' => t('Recipients'),
      '#description' => t('Enter one or more recipients, separated by a comma.'),
      '#required' => TRUE,
    );

    $form['body'] = array(
      '#type' => 'textarea',
      '#title' => t('Body'),
      '#required' => TRUE,
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Send message'),
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\messagebird\MessageBirdMessage $messagebird */
    $messagebird = \Drupal::service('messagebird.message');

    $message = $messagebird->sendMessage($form_state->getValue('body'), $form_state->getValue('recipients'), $form_state->getValue('originator'));

    if (empty($message->recipients->items)) {
      drupal_set_message(t('Failed to send message.'), 'error');
      return;
    }

    /** @var Recipient $recipient */
    foreach ($message->recipients->items as $recipient) {
      $args = array('@recipient' => $recipient->recipient);

      if ($recipient->status != 'sent') {
        drupal_set_message(t('Failed to sent to @recipient.', $args), 'warning');
        continue;
      }

      drupal_set_message(t('Successfully sent to @recipient.', $args), 'status');
    }
  }

}
