<?php

namespace Drupal\messagebird;

use MessageBird\Objects\Lookup;

/**
 * Interface MessageBirdLookupInterface.
 *
 * @package Drupal\messagebird
 */
interface MessageBirdLookupInterface {

  /**
   * Look up a phone number.
   *
   * @param string $number
   *   Phone number, accepts multiple formats.
   * @param string|null $country_code
   *   (optional) ISO 3166-2 country code.
   *
   * @return \MessageBird\Objects\Lookup|null
   *   Full Lookup object or NULL on failure.
   */
  public function lookupNumber($number, $country_code = NULL);

  /**
   * Get the full MessageBird Lookup object.
   *
   * @param \MessageBird\Objects\Lookup $lookup
   *   Lookup object.
   * @param string $format
   *   Preferred phone number format, defaults to e146.
   *
   * @return string
   *   The preferred formatted phone number or empty on failure.
   */
  public function getPhoneNumber(Lookup $lookup, $format = NULL);

}
